@@ -70,6 +70,8 @@ def nolog(level='warning'):
 class URITemplate(uritemplate.URITemplate):
 
     def __eq__(self, other):
+        if isinstance(other, str):
+            return self.uri == other
         if not hasattr(other, 'uri'):
             return False
         return super(URITemplate, self).__eq__(other)
@@ -271,23 +273,34 @@ class Datatype(DescriptionBase):
         raise ValueError(v)
 
     def __attrs_post_init__(self):
+        for attr_ in [
+            'minimum', 'maximum', 'minInclusive', 'maxInclusive', 'minExclusive', 'maxExclusive'
+        ]:
+            if getattr(self, attr_) is not None:
+                setattr(self, attr_, self.parse(getattr(self, attr_)))
+
         if self.length is not None:
             if self.minLength is not None and self.length < self.minLength:
-                raise ValueError()
+                raise ValueError('minLength > length')
 
             if self.maxLength is not None:
                 if self.length > self.maxLength:
-                    raise ValueError()
+                    raise ValueError('maxLength < length')
 
         if self.minLength is not None and self.maxLength is not None \
                 and self.minLength > self.maxLength:
-            raise ValueError()
+            raise ValueError('minLength > maxLength')
 
         if not isinstance(self.derived_description, dict):
             raise ValueError()  # pragma: no cover
 
     def asdict(self, omit_defaults=True):
         res = DescriptionBase.asdict(self, omit_defaults=omit_defaults)
+        for attr_ in [
+            'minimum', 'maximum', 'minInclusive', 'maxInclusive', 'minExclusive', 'maxExclusive'
+        ]:
+            if attr_ in res:
+                res[attr_] = self.formatted(res[attr_])
         if len(res) == 1 and 'base' in res:
             return res['base']
         return res
@@ -314,18 +327,18 @@ class Datatype(DescriptionBase):
         try:
             l_ = len(v or '')
             if self.length is not None and l_ != self.length:
-                raise ValueError()
+                raise ValueError('value must have length {}'.format(self.length))
             if self.minLength is not None and l_ < self.minLength:
-                raise ValueError()
+                raise ValueError('value must have at least length {}'.format(self.minLength))
             if self.maxLength is not None and l_ > self.maxLength:
-                raise ValueError()
+                raise ValueError('value must have at most length {}'.format(self.maxLength))
         except TypeError:
             pass
         if self.basetype.minmax:
             if self.minimum is not None and v < self.minimum:
-                raise ValueError()
+                raise ValueError('value must be >= {}'.format(self.minimum))
             if self.maximum is not None and v > self.maximum:
-                raise ValueError()
+                raise ValueError('value must be <= {}'.format(self.maximum))
         return v
 
     def read(self, v):
@@ -564,8 +577,7 @@ class TableLike(Description):
         return res
 
     def to_file(self, fname, omit_defaults=True):
-        if not isinstance(fname, pathlib.Path):
-            fname = pathlib.Path(fname)
+        fname = utils.ensure_path(fname)
         data = self.asdict(omit_defaults=omit_defaults)
         with json_open(str(fname), 'w') as f:
             json.dump(data, f, indent=4, separators=(',', ': '))
@@ -841,12 +853,8 @@ class TableGroup(TableLike):
     def tabledict(self):
         return {t.local_name: t for t in self.tables}
 
-    def check_referential_integrity(self, data=None, log=None):
-        success = True
-        if data is not None:
-            warnings.warn('the data argument of check_referential_integrity '
-                          'is deprecated (its content will be ignored)')  # pragma: no cover
-        fkeys = [
+    def foreign_keys(self):
+        return [
             (
                 self.tabledict[fk.reference.resource.string],
                 fk.reference.columnReference,
@@ -854,6 +862,38 @@ class TableGroup(TableLike):
                 fk.columnReference)
             for t in self.tables for fk in t.tableSchema.foreignKeys
             if not fk.reference.schemaReference]
+
+    def validate_schema(self):
+        try:
+            for st, sc, tt, tc in self.foreign_keys():
+                if len(sc) != len(tc):
+                    raise ValueError(
+                        'Foreign key error: non-matching number of columns in source and target')
+                for scol, tcol in zip(sc, tc):
+                    scolumn = st.tableSchema.get_column(scol)
+                    tcolumn = tt.tableSchema.get_column(tcol)
+                    if not (scolumn and tcolumn):
+                        raise ValueError(
+                            'Foregin key error: missing column "{}" or "{}"'.format(scol, tcol))
+                    if scolumn.datatype and tcolumn.datatype and \
+                            scolumn.datatype.base != tcolumn.datatype.base:
+                        raise ValueError(
+                            'Foregin key error: non-matching datatype "{}:{}" or "{}:{}"'.format(
+                                scol, scolumn.datatype.base, tcol, tcolumn.datatype.base))
+        except KeyError as e:
+            raise ValueError('Foreign key error: missing table "{}" referenced'.format(e))
+
+    def check_referential_integrity(self, data=None, log=None):
+        if data is not None:
+            warnings.warn('the data argument of check_referential_integrity '
+                          'is deprecated (its content will be ignored)')  # pragma: no cover
+        try:
+            self.validate_schema()
+            success = True
+        except ValueError as e:
+            success = False
+            log_or_raise(str(e), log=log, level='error')
+        fkeys = self.foreign_keys()
         # FIXME: We only support Foreign Key references between tables!
         fkeys = sorted(fkeys, key=lambda x: (x[0].local_name, x[1], x[2].local_name))
         # Grouping by local_name of tables - even though we'd like to have the table objects
